@@ -21,6 +21,7 @@
 // calls are made to indicate what's going on during the load...
 //============================================================================
 using System;
+using System.Diagnostics;
 using System.Globalization;
 using System.IO;
 using System.Reflection;
@@ -37,9 +38,7 @@ public class clrModule
     public static void initclr()
 #endif
     {
-#if DEBUG
-        Console.WriteLine("Attempting to load Python.Runtime using standard binding rules... ");
-#endif
+        DebugPrint("Attempting to load 'Python.Runtime' using standard binding rules.");
 #if USE_PYTHON_RUNTIME_PUBLIC_KEY_TOKEN
         var pythonRuntimePublicKeyTokenData = new byte[] { 0x50, 0x00, 0xfe, 0xa6, 0xcb, 0xa7, 0x02, 0xdd };
 #endif
@@ -53,7 +52,8 @@ public class clrModule
         var pythonRuntimeName = new AssemblyName("Python.Runtime")
         {
 #if USE_PYTHON_RUNTIME_VERSION
-            Version = new Version("4.0.0.1"),
+            // Has no effect until SNK works. Keep updated anyways.
+            Version = new Version("2.3.0"),
 #endif
             CultureInfo = CultureInfo.InvariantCulture
         };
@@ -65,12 +65,11 @@ public class clrModule
         try
         {
             pythonRuntime = Assembly.Load(pythonRuntimeName);
-#if DEBUG
-            Console.WriteLine("Success!");
-#endif
+            DebugPrint("Success loading 'Python.Runtime' using standard binding rules.");
         }
         catch (IOException)
         {
+            DebugPrint("'Python.Runtime' not found using standard binding rules.");
             try
             {
                 // If the above fails for any reason, we fallback to attempting to load "Python.Runtime.dll"
@@ -89,16 +88,13 @@ public class clrModule
                     throw new InvalidOperationException(executingAssembly.Location);
                 }
                 string pythonRuntimeDllPath = Path.Combine(assemblyDirectory, "Python.Runtime.dll");
-#if DEBUG
-                Console.WriteLine("Attempting to load Python.Runtime from: '{0}'...", pythonRuntimeDllPath);
-#endif
+                DebugPrint($"Attempting to load Python.Runtime from: '{pythonRuntimeDllPath}'.");
                 pythonRuntime = Assembly.LoadFrom(pythonRuntimeDllPath);
+                DebugPrint($"Success loading 'Python.Runtime' from: '{pythonRuntimeDllPath}'.");
             }
             catch (InvalidOperationException)
             {
-#if DEBUG
-                Console.WriteLine("Could not load Python.Runtime");
-#endif
+                DebugPrint("Could not load 'Python.Runtime'.");
 #if PYTHON3
                 return IntPtr.Zero;
 #elif PYTHON2
@@ -117,4 +113,14 @@ public class clrModule
         pythonEngineType.InvokeMember("InitExt", BindingFlags.InvokeMethod, null, null, null);
 #endif
     }
+
+    /// <summary>
+    /// Substitute for Debug.Writeline(...). Ideally we would use Debug.Writeline
+    /// but haven't been able to configure the TRACE from within Python.
+    /// </summary>
+    [Conditional("DEBUG")]
+    private static void DebugPrint(string str)
+    {
+        Console.WriteLine(str);
+    }
 }
