@@ -1,10 +1,19 @@
 using System;
 using System.Collections.Generic;
+using System.IO;
 using System.Reflection;
 using Python.Runtime;
 
 namespace Python.Runtime
 {
+    /// <summary>
+    /// Example of Embedding Python inside of a .NET program.
+    /// </summary>
+    /// <remarks>
+    /// It has similar functionality to doing `import clr` from within Python, but this does it
+    /// the other way around; That is, it loads Python inside of .NET program.
+    /// See https://github.com/pythonnet/pythonnet/issues/358 for more info.
+    /// </remarks>
     public sealed class PythonConsole
     {
         private static AssemblyLoader assemblyLoader = new AssemblyLoader();
@@ -32,7 +41,7 @@ namespace Python.Runtime
         // (Python.Runtime.dll is included as a resource)
         private sealed class AssemblyLoader
         {
-            Dictionary<string, Assembly> loadedAssemblies;
+            private Dictionary<string, Assembly> loadedAssemblies;
 
             public AssemblyLoader()
             {
@@ -41,7 +50,7 @@ namespace Python.Runtime
                 AppDomain.CurrentDomain.AssemblyResolve += (sender, args) =>
                 {
                     string shortName = args.Name.Split(',')[0];
-                    string resourceName = string.Format("{0}.dll", shortName);
+                    string resourceName = $"{shortName}.dll";
 
                     if (loadedAssemblies.ContainsKey(resourceName))
                     {
@@ -49,7 +58,7 @@ namespace Python.Runtime
                     }
 
                     // looks for the assembly from the resources and load it
-                    using (var stream = Assembly.GetExecutingAssembly().GetManifestResourceStream(resourceName))
+                    using (Stream stream = Assembly.GetExecutingAssembly().GetManifestResourceStream(resourceName))
                     {
                         if (stream != null)
                         {
@@ -60,7 +69,6 @@ namespace Python.Runtime
                             return assembly;
                         }
                     }
-
                     return null;
                 };
             }
