@@ -1,9 +1,9 @@
 using System;
 using System.Collections;
-using System.IO;
 using System.Collections.Concurrent;
 using System.Collections.Generic;
 using System.Diagnostics;
+using System.IO;
 using System.Reflection;
 using System.Threading;
 
@@ -17,30 +17,30 @@ namespace Python.Runtime
     {
         // modified from event handlers below, potentially triggered from different .NET threads
         // therefore this should be a ConcurrentDictionary
-        static ConcurrentDictionary<string, ConcurrentDictionary<Assembly, string>> namespaces;
-        //static Dictionary<string, Dictionary<string, string>> generics;
-        static AssemblyLoadEventHandler lhandler;
-        static ResolveEventHandler rhandler;
+        private static ConcurrentDictionary<string, ConcurrentDictionary<Assembly, string>> namespaces;
+        //private static Dictionary<string, Dictionary<string, string>> generics;
+        private static AssemblyLoadEventHandler lhandler;
+        private static ResolveEventHandler rhandler;
+
         // updated only under GIL?
-        static Dictionary<string, int> probed;
+        private static Dictionary<string, int> probed;
+
         // modified from event handlers below, potentially triggered from different .NET threads
-        static AssemblyList assemblies;
+        private static AssemblyList assemblies;
         internal static List<string> pypath;
 
         private AssemblyManager()
         {
         }
 
-        //===================================================================
-        // Initialization performed on startup of the Python runtime. Here we
-        // scan all of the currently loaded assemblies to determine exported
-        // names, and register to be notified of new assembly loads.
-        //===================================================================
-
+        /// <summary>
+        /// Initialization performed on startup of the Python runtime. Here we
+        /// scan all of the currently loaded assemblies to determine exported
+        /// names, and register to be notified of new assembly loads.
+        /// </summary>
         internal static void Initialize()
         {
-            namespaces = new
-                ConcurrentDictionary<string, ConcurrentDictionary<Assembly, string>>();
+            namespaces = new ConcurrentDictionary<string, ConcurrentDictionary<Assembly, string>>();
             probed = new Dictionary<string, int>(32);
             //generics = new Dictionary<string, Dictionary<string, string>>();
             assemblies = new AssemblyList(16);
@@ -55,7 +55,7 @@ namespace Python.Runtime
             domain.AssemblyResolve += rhandler;
 
             Assembly[] items = domain.GetAssemblies();
-            foreach (var a in items)
+            foreach (Assembly a in items)
             {
                 try
                 {
@@ -64,16 +64,15 @@ namespace Python.Runtime
                 }
                 catch (Exception ex)
                 {
-                    Debug.WriteLine(string.Format("Error scanning assembly {0}. {1}", a, ex));
+                    Debug.WriteLine("Error scanning assembly {0}. {1}", a, ex);
                 }
             }
         }
 
 
-        //===================================================================
-        // Cleanup resources upon shutdown of the Python runtime.
-        //===================================================================
-
+        /// <summary>
+        /// Cleanup resources upon shutdown of the Python runtime.
+        /// </summary>
         internal static void Shutdown()
         {
             AppDomain domain = AppDomain.CurrentDomain;
@@ -82,15 +81,14 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Event handler for assembly load events. At the time the Python
-        // runtime loads, we scan the app domain to map the assemblies that
-        // are loaded at the time. We also have to register this event handler
-        // so that we can know about assemblies that get loaded after the
-        // Python runtime is initialized.
-        //===================================================================
-
-        static void AssemblyLoadHandler(Object ob, AssemblyLoadEventArgs args)
+        /// <summary>
+        /// Event handler for assembly load events. At the time the Python
+        /// runtime loads, we scan the app domain to map the assemblies that
+        /// are loaded at the time. We also have to register this event handler
+        /// so that we can know about assemblies that get loaded after the
+        /// Python runtime is initialized.
+        /// </summary>
+        private static void AssemblyLoadHandler(object ob, AssemblyLoadEventArgs args)
         {
             Assembly assembly = args.LoadedAssembly;
             assemblies.Add(assembly);
@@ -98,15 +96,14 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Event handler for assembly resolve events. This is needed because
-        // we augment the assembly search path with the PYTHONPATH when we
-        // load an assembly from Python. Because of that, we need to listen
-        // for failed loads, because they might be dependencies of something
-        // we loaded from Python which also needs to be found on PYTHONPATH.
-        //===================================================================
-
-        static Assembly ResolveHandler(Object ob, ResolveEventArgs args)
+        /// <summary>
+        /// Event handler for assembly resolve events. This is needed because
+        /// we augment the assembly search path with the PYTHONPATH when we
+        /// load an assembly from Python. Because of that, we need to listen
+        /// for failed loads, because they might be dependencies of something
+        /// we loaded from Python which also needs to be found on PYTHONPATH.
+        /// </summary>
+        private static Assembly ResolveHandler(object ob, ResolveEventArgs args)
         {
             string name = args.Name.ToLower();
             foreach (Assembly a in assemblies)
@@ -121,19 +118,17 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // We __really__ want to avoid using Python objects or APIs when
-        // probing for assemblies to load, since our ResolveHandler may be
-        // called in contexts where we don't have the Python GIL and can't
-        // even safely try to get it without risking a deadlock ;(
-        //
-        // To work around that, we update a managed copy of sys.path (which
-        // is the main thing we care about) when UpdatePath is called. The
-        // import hook calls this whenever it knows its about to use the
-        // assembly manager, which lets us keep up with changes to sys.path
-        // in a relatively lightweight and low-overhead way.
-        //===================================================================
-
+        /// <summary>
+        /// We __really__ want to avoid using Python objects or APIs when
+        /// probing for assemblies to load, since our ResolveHandler may be
+        /// called in contexts where we don't have the Python GIL and can't
+        /// even safely try to get it without risking a deadlock ;(
+        /// To work around that, we update a managed copy of sys.path (which
+        /// is the main thing we care about) when UpdatePath is called. The
+        /// import hook calls this whenever it knows its about to use the
+        /// assembly manager, which lets us keep up with changes to sys.path
+        /// in a relatively lightweight and low-overhead way.
+        /// </summary>
         internal static void UpdatePath()
         {
             IntPtr list = Runtime.PySys_GetObject("path");
@@ -142,7 +137,7 @@ namespace Python.Runtime
             {
                 pypath.Clear();
                 probed.Clear();
-                for (int i = 0; i < count; i++)
+                for (var i = 0; i < count; i++)
                 {
                     IntPtr item = Runtime.PyList_GetItem(list, i);
                     string path = Runtime.GetManagedString(item);
@@ -155,21 +150,18 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Given an assembly name, try to find this assembly file using the
-        // PYTHONPATH. If not found, return null to indicate implicit load
-        // using standard load semantics (app base directory then GAC, etc.)
-        //===================================================================
-
+        /// <summary>
+        /// Given an assembly name, try to find this assembly file using the
+        /// PYTHONPATH. If not found, return null to indicate implicit load
+        /// using standard load semantics (app base directory then GAC, etc.)
+        /// </summary>
         public static string FindAssembly(string name)
         {
             char sep = Path.DirectorySeparatorChar;
-            string path;
-            string temp;
 
-            for (int i = 0; i < pypath.Count; i++)
+            foreach (string head in pypath)
             {
-                string head = pypath[i];
+                string path;
                 if (head == null || head.Length == 0)
                 {
                     path = name;
@@ -179,11 +171,12 @@ namespace Python.Runtime
                     path = head + sep + name;
                 }
 
-                temp = path + ".dll";
+                string temp = path + ".dll";
                 if (File.Exists(temp))
                 {
                     return temp;
                 }
+
                 temp = path + ".exe";
                 if (File.Exists(temp))
                 {
@@ -194,11 +187,10 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Loads an assembly from the application directory or the GAC
-        // given a simple assembly name. Returns the assembly if loaded.
-        //===================================================================
-
+        /// <summary>
+        /// Loads an assembly from the application directory or the GAC
+        /// given a simple assembly name. Returns the assembly if loaded.
+        /// </summary>
         public static Assembly LoadAssembly(string name)
         {
             Assembly assembly = null;
@@ -206,9 +198,10 @@ namespace Python.Runtime
             {
                 assembly = Assembly.Load(name);
             }
-            catch (System.Exception e)
+            catch (Exception)
             {
-                //if (!(e is System.IO.FileNotFoundException)) {
+                //if (!(e is System.IO.FileNotFoundException))
+                //{
                 //    throw;
                 //}
             }
@@ -216,10 +209,9 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Loads an assembly using an augmented search path (the python path).
-        //===================================================================
-
+        /// <summary>
+        /// Loads an assembly using an augmented search path (the python path).
+        /// </summary>
         public static Assembly LoadAssemblyPath(string name)
         {
             string path = FindAssembly(name);
@@ -230,7 +222,7 @@ namespace Python.Runtime
                 {
                     assembly = Assembly.LoadFrom(path);
                 }
-                catch
+                catch (Exception)
                 {
                 }
             }
@@ -248,14 +240,16 @@ namespace Python.Runtime
             if (Path.IsPathRooted(name))
             {
                 if (!Path.HasExtension(name))
+                {
                     name = name + ".dll";
+                }
                 if (File.Exists(name))
                 {
                     try
                     {
                         assembly = Assembly.LoadFrom(name);
                     }
-                    catch
+                    catch (Exception)
                     {
                     }
                 }
@@ -263,10 +257,9 @@ namespace Python.Runtime
             return assembly;
         }
 
-        //===================================================================
-        // Returns an assembly that's already been loaded
-        //===================================================================
-
+        /// <summary>
+        /// Returns an assembly that's already been loaded
+        /// </summary>
         public static Assembly FindLoadedAssembly(string name)
         {
             foreach (Assembly a in assemblies)
@@ -279,28 +272,29 @@ namespace Python.Runtime
             return null;
         }
 
-        //===================================================================
-        // Given a qualified name of the form A.B.C.D, attempt to load
-        // an assembly named after each of A.B.C.D, A.B.C, A.B, A. This
-        // will only actually probe for the assembly once for each unique
-        // namespace. Returns true if any assemblies were loaded.
-        // TODO item 3 "* Deprecate implicit loading of assemblies":
-        //  Set the fromFile flag if the name of the loaded assembly matches
-        //  the fully qualified name that was requested if the framework
-        //  actually loads an assembly.
-        // Call ONLY for namespaces that HAVE NOT been cached yet.
-        //===================================================================
-
+        /// <summary>
+        /// Given a qualified name of the form A.B.C.D, attempt to load
+        /// an assembly named after each of A.B.C.D, A.B.C, A.B, A. This
+        /// will only actually probe for the assembly once for each unique
+        /// namespace. Returns true if any assemblies were loaded.
+        /// </summary>
+        /// <remarks>
+        /// TODO item 3 "* Deprecate implicit loading of assemblies":
+        /// Set the fromFile flag if the name of the loaded assembly matches
+        /// the fully qualified name that was requested if the framework
+        /// actually loads an assembly.
+        /// Call ONLY for namespaces that HAVE NOT been cached yet.
+        /// </remarks>
         public static bool LoadImplicit(string name, bool warn = true)
         {
             string[] names = name.Split('.');
-            bool loaded = false;
-            string s = "";
+            var loaded = false;
+            var s = "";
             Assembly lastAssembly = null;
             HashSet<Assembly> assembliesSet = null;
-            for (int i = 0; i < names.Length; i++)
+            for (var i = 0; i < names.Length; i++)
             {
-                s = (i == 0) ? names[0] : s + "." + names[i];
+                s = i == 0 ? names[0] : s + "." + names[i];
                 if (!probed.ContainsKey(s))
                 {
                     if (assembliesSet == null)
@@ -328,10 +322,9 @@ namespace Python.Runtime
             // Deprecation warning
             if (warn && loaded)
             {
-                string deprWarning = String.Format(
-                    "\nThe module was found, but not in a referenced namespace.\n" +
-                    "Implicit loading is deprecated. Please use clr.AddReference(\"{0}\").",
-                    Path.GetFileNameWithoutExtension(lastAssembly.Location));
+                string location = Path.GetFileNameWithoutExtension(lastAssembly.Location);
+                string deprWarning = "The module was found, but not in a referenced namespace.\n" +
+                                     $"Implicit loading is deprecated. Please use clr.AddReference('{location}').";
                 Exceptions.deprecation(deprWarning);
             }
 
@@ -339,13 +332,12 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Scans an assembly for exported namespaces, adding them to the
-        // mapping of valid namespaces. Note that for a given namespace
-        // a.b.c.d, each of a, a.b, a.b.c and a.b.c.d are considered to
-        // be valid namespaces (to better match Python import semantics).
-        //===================================================================
-
+        /// <summary>
+        /// Scans an assembly for exported namespaces, adding them to the
+        /// mapping of valid namespaces. Note that for a given namespace
+        /// a.b.c.d, each of a, a.b, a.b.c and a.b.c.d are considered to
+        /// be valid namespaces (to better match Python import semantics).
+        /// </summary>
         internal static void ScanAssembly(Assembly assembly)
         {
             // A couple of things we want to do here: first, we want to
@@ -353,24 +345,23 @@ namespace Python.Runtime
             // the assembly.
 
             Type[] types = assembly.GetTypes();
-            for (int i = 0; i < types.Length; i++)
+            foreach (Type t in types)
             {
-                Type t = types[i];
                 string ns = t.Namespace ?? "";
                 if (!namespaces.ContainsKey(ns))
                 {
                     string[] names = ns.Split('.');
-                    string s = "";
-                    for (int n = 0; n < names.Length; n++)
+                    var s = "";
+                    for (var n = 0; n < names.Length; n++)
                     {
-                        s = (n == 0) ? names[0] : s + "." + names[n];
+                        s = n == 0 ? names[0] : s + "." + names[n];
                         namespaces.TryAdd(s, new ConcurrentDictionary<Assembly, string>());
                     }
                 }
 
                 if (ns != null)
                 {
-                    namespaces[ns].TryAdd(assembly, String.Empty);
+                    namespaces[ns].TryAdd(assembly, string.Empty);
                 }
 
                 if (ns != null && t.IsGenericTypeDefinition)
@@ -382,7 +373,7 @@ namespace Python.Runtime
 
         public static AssemblyName[] ListAssemblies()
         {
-            List<AssemblyName> names = new List<AssemblyName>(assemblies.Count);
+            var names = new List<AssemblyName>(assemblies.Count);
             foreach (Assembly assembly in assemblies)
             {
                 names.Add(assembly.GetName());
@@ -390,36 +381,30 @@ namespace Python.Runtime
             return names.ToArray();
         }
 
-        //===================================================================
-        // Returns true if the given qualified name matches a namespace
-        // exported by an assembly loaded in the current app domain.
-        //===================================================================
-
+        /// <summary>
+        /// Returns true if the given qualified name matches a namespace
+        /// exported by an assembly loaded in the current app domain.
+        /// </summary>
         public static bool IsValidNamespace(string name)
         {
-            return !String.IsNullOrEmpty(name) && namespaces.ContainsKey(name);
+            return !string.IsNullOrEmpty(name) && namespaces.ContainsKey(name);
         }
 
-        //===================================================================
-        // Returns list of assemblies that declare types in a given namespace
-        //===================================================================
-
+        /// <summary>
+        /// Returns list of assemblies that declare types in a given namespace
+        /// </summary>
         public static IEnumerable<Assembly> GetAssemblies(string nsname)
         {
-            if (!namespaces.ContainsKey(nsname))
-                return new List<Assembly>();
-
-            return namespaces[nsname].Keys;
+            return !namespaces.ContainsKey(nsname) ? new List<Assembly>() : namespaces[nsname].Keys;
         }
 
-        //===================================================================
-        // Returns the current list of valid names for the input namespace.
-        //===================================================================
-
+        /// <summary>
+        /// Returns the current list of valid names for the input namespace.
+        /// </summary>
         public static List<string> GetNames(string nsname)
         {
             //Dictionary<string, int> seen = new Dictionary<string, int>();
-            List<string> names = new List<string>(8);
+            var names = new List<string>(8);
 
             List<string> g = GenericUtil.GetGenericBaseNames(nsname);
             if (g != null)
@@ -435,9 +420,8 @@ namespace Python.Runtime
                 foreach (Assembly a in namespaces[nsname].Keys)
                 {
                     Type[] types = a.GetTypes();
-                    for (int i = 0; i < types.Length; i++)
+                    foreach (Type t in types)
                     {
-                        Type t = types[i];
                         if ((t.Namespace ?? "") == nsname)
                         {
                             names.Add(t.Name);
@@ -460,12 +444,11 @@ namespace Python.Runtime
             return names;
         }
 
-        //===================================================================
-        // Returns the System.Type object for a given qualified name,
-        // looking in the currently loaded assemblies for the named
-        // type. Returns null if the named type cannot be found.
-        //===================================================================
-
+        /// <summary>
+        /// Returns the System.Type object for a given qualified name,
+        /// looking in the currently loaded assemblies for the named
+        /// type. Returns null if the named type cannot be found.
+        /// </summary>
         public static Type LookupType(string qname)
         {
             foreach (Assembly assembly in assemblies)
@@ -480,13 +463,15 @@ namespace Python.Runtime
         }
 
         /// <summary>
-        /// Wrapper around List<Assembly> for thread safe access
+        /// Wrapper around List&lt;Assembly&gt; for thread safe access
         /// </summary>
-        private class AssemblyList : IEnumerable<Assembly>{
+        private class AssemblyList : IEnumerable<Assembly>
+        {
             private readonly List<Assembly> _list;
             private readonly ReaderWriterLockSlim _lock;
 
-            public AssemblyList(int capacity) {
+            public AssemblyList(int capacity)
+            {
                 _list = new List<Assembly>(capacity);
                 _lock = new ReaderWriterLockSlim();
             }
@@ -496,16 +481,19 @@ namespace Python.Runtime
                 get
                 {
                     _lock.EnterReadLock();
-                    try {
+                    try
+                    {
                         return _list.Count;
                     }
-                    finally {
+                    finally
+                    {
                         _lock.ExitReadLock();
                     }
                 }
             }
 
-            public void Add(Assembly assembly) {
+            public void Add(Assembly assembly)
+            {
                 _lock.EnterWriteLock();
                 try
                 {
@@ -519,12 +507,12 @@ namespace Python.Runtime
 
             public IEnumerator GetEnumerator()
             {
-                return ((IEnumerable<Assembly>) this).GetEnumerator();
+                return ((IEnumerable<Assembly>)this).GetEnumerator();
             }
 
             /// <summary>
-            /// Enumerator wrapping around <see cref="AssemblyList._list"/>'s enumerator.
-            /// Acquires and releases a read lock on <see cref="AssemblyList._lock"/> during enumeration
+            /// Enumerator wrapping around <see cref="AssemblyList._list" />'s enumerator.
+            /// Acquires and releases a read lock on <see cref="AssemblyList._lock" /> during enumeration
             /// </summary>
             private class Enumerator : IEnumerator<Assembly>
             {
@@ -555,9 +543,15 @@ namespace Python.Runtime
                     _listEnumerator.Reset();
                 }
 
-                public Assembly Current { get { return _listEnumerator.Current; } }
+                public Assembly Current
+                {
+                    get { return _listEnumerator.Current; }
+                }
 
-                object IEnumerator.Current { get { return Current; } }
+                object IEnumerator.Current
+                {
+                    get { return Current; }
+                }
             }
 
             IEnumerator<Assembly> IEnumerable<Assembly>.GetEnumerator()
