@@ -1,7 +1,5 @@
 using System;
 using System.Collections;
-using System.Reflection;
-using System.Security;
 using System.Runtime.InteropServices;
 
 namespace Python.Runtime
@@ -19,7 +17,7 @@ namespace Python.Runtime
         internal Indexer indexer;
         internal Type type;
 
-        internal ClassBase(Type tp) : base()
+        internal ClassBase(Type tp)
         {
             indexer = null;
             type = tp;
@@ -27,22 +25,20 @@ namespace Python.Runtime
 
         internal virtual bool CanSubclass()
         {
-            return (!this.type.IsEnum);
+            return !type.IsEnum;
         }
 
-        //====================================================================
-        // Implements __init__ for reflected classes and value types.
-        //====================================================================
-
+        /// <summary>
+        /// Implements __init__ for reflected classes and value types.
+        /// </summary>
         public static int tp_init(IntPtr ob, IntPtr args, IntPtr kw)
         {
             return 0;
         }
 
-        //====================================================================
-        // Default implementation of [] semantics for reflected types.
-        //====================================================================
-
+        /// <summary>
+        /// Default implementation of [] semantics for reflected types.
+        /// </summary>
         public virtual IntPtr type_subscript(IntPtr idx)
         {
             Type[] types = Runtime.PythonArgsToTypeArray(idx);
@@ -51,12 +47,12 @@ namespace Python.Runtime
                 return Exceptions.RaiseTypeError("type(s) expected");
             }
 
-            Type target = GenericUtil.GenericForType(this.type, types.Length);
+            Type target = GenericUtil.GenericForType(type, types.Length);
 
             if (target != null)
             {
                 Type t = target.MakeGenericType(types);
-                ManagedType c = (ManagedType)ClassManager.GetClass(t);
+                ManagedType c = ClassManager.GetClass(t);
                 Runtime.XIncref(c.pyHandle);
                 return c.pyHandle;
             }
@@ -64,11 +60,11 @@ namespace Python.Runtime
             return Exceptions.RaiseTypeError("no type matches params");
         }
 
-        //====================================================================
-        // Standard comparison implementation for instances of reflected types.
-        //====================================================================
-
-        public static IntPtr tp_richcompare(IntPtr ob, IntPtr other, int op) {
+        /// <summary>
+        /// Standard comparison implementation for instances of reflected types.
+        /// </summary>
+        public static IntPtr tp_richcompare(IntPtr ob, IntPtr other, int op)
+        {
             CLRObject co1;
             CLRObject co2;
             switch (op)
@@ -99,10 +95,10 @@ namespace Python.Runtime
                         return pyfalse;
                     }
 
-                    Object o1 = co1.inst;
-                    Object o2 = co2.inst;
+                    object o1 = co1.inst;
+                    object o2 = co2.inst;
 
-                    if (Object.Equals(o1, o2))
+                    if (Equals(o1, o2))
                     {
                         Runtime.XIncref(pytrue);
                         return pytrue;
@@ -116,14 +112,19 @@ namespace Python.Runtime
                 case Runtime.Py_GE:
                     co1 = GetManagedObject(ob) as CLRObject;
                     co2 = GetManagedObject(other) as CLRObject;
-                    if(co1 == null || co2 == null)
+                    if (co1 == null || co2 == null)
+                    {
                         return Exceptions.RaiseTypeError("Cannot get managed object");
+                    }
                     var co1Comp = co1.inst as IComparable;
                     if (co1Comp == null)
-                        return Exceptions.RaiseTypeError("Cannot convert object of type " + co1.GetType() + " to IComparable");
+                    {
+                        Type co1Type = co1.GetType();
+                        return Exceptions.RaiseTypeError($"Cannot convert object of type {co1Type} to IComparable");
+                    }
                     try
                     {
-                        var cmp = co1Comp.CompareTo(co2.inst);
+                        int cmp = co1Comp.CompareTo(co2.inst);
 
                         IntPtr pyCmp;
                         if (cmp < 0)
@@ -150,10 +151,12 @@ namespace Python.Runtime
                         }
                         else
                         {
-                            if (op == Runtime.Py_GE || op == Runtime.Py_GT) {
+                            if (op == Runtime.Py_GE || op == Runtime.Py_GT)
+                            {
                                 pyCmp = Runtime.PyTrue;
                             }
-                            else {
+                            else
+                            {
                                 pyCmp = Runtime.PyFalse;
                             }
                         }
@@ -170,21 +173,20 @@ namespace Python.Runtime
             }
         }
 
-        //====================================================================
-        // Standard iteration support for instances of reflected types. This
-        // allows natural iteration over objects that either are IEnumerable
-        // or themselves support IEnumerator directly.
-        //====================================================================
-
+        /// <summary>
+        /// Standard iteration support for instances of reflected types. This
+        /// allows natural iteration over objects that either are IEnumerable
+        /// or themselves support IEnumerator directly.
+        /// </summary>
         public static IntPtr tp_iter(IntPtr ob)
         {
-            CLRObject co = GetManagedObject(ob) as CLRObject;
+            var co = GetManagedObject(ob) as CLRObject;
             if (co == null)
             {
                 return Exceptions.RaiseTypeError("invalid object");
             }
 
-            IEnumerable e = co.inst as IEnumerable;
+            var e = co.inst as IEnumerable;
             IEnumerator o;
 
             if (e != null)
@@ -197,8 +199,7 @@ namespace Python.Runtime
 
                 if (o == null)
                 {
-                    string message = "iteration over non-sequence";
-                    return Exceptions.RaiseTypeError(message);
+                    return Exceptions.RaiseTypeError("iteration over non-sequence");
                 }
             }
 
@@ -206,13 +207,12 @@ namespace Python.Runtime
         }
 
 
-        //====================================================================
-        // Standard __hash__ implementation for instances of reflected types.
-        //====================================================================
-
+        /// <summary>
+        /// Standard __hash__ implementation for instances of reflected types.
+        /// </summary>
         public static IntPtr tp_hash(IntPtr ob)
         {
-            CLRObject co = GetManagedObject(ob) as CLRObject;
+            var co = GetManagedObject(ob) as CLRObject;
             if (co == null)
             {
                 return Exceptions.RaiseTypeError("unhashable type");
@@ -221,13 +221,12 @@ namespace Python.Runtime
         }
 
 
-        //====================================================================
-        // Standard __str__ implementation for instances of reflected types.
-        //====================================================================
-
+        /// <summary>
+        /// Standard __str__ implementation for instances of reflected types.
+        /// </summary>
         public static IntPtr tp_str(IntPtr ob)
         {
-            CLRObject co = GetManagedObject(ob) as CLRObject;
+            var co = GetManagedObject(ob) as CLRObject;
             if (co == null)
             {
                 return Exceptions.RaiseTypeError("invalid object");
@@ -248,10 +247,9 @@ namespace Python.Runtime
         }
 
 
-        //====================================================================
-        // Default implementations for required Python GC support.
-        //====================================================================
-
+        /// <summary>
+        /// Default implementations for required Python GC support.
+        /// </summary>
         public static int tp_traverse(IntPtr ob, IntPtr func, IntPtr args)
         {
             return 0;
@@ -267,10 +265,9 @@ namespace Python.Runtime
             return 1;
         }
 
-        //====================================================================
-        // Standard dealloc implementation for instances of reflected types.
-        //====================================================================
-
+        /// <summary>
+        /// Standard dealloc implementation for instances of reflected types.
+        /// </summary>
         public static void tp_dealloc(IntPtr ob)
         {
             ManagedType self = GetManagedObject(ob);
@@ -285,4 +282,4 @@ namespace Python.Runtime
             self.gcHandle.Free();
         }
     }
-}
\ No newline at end of file
+}
