@@ -3,35 +3,33 @@ using System.Reflection;
 
 namespace Python.Runtime
 {
-    //========================================================================
-    // A ConstructorBinder encapsulates information about one or more managed
-    // constructors, and is responsible for selecting the right constructor
-    // given a set of Python arguments. This is slightly different than the
-    // standard MethodBinder because of a difference in invoking constructors
-    // using reflection (which is seems to be a CLR bug).
-    //========================================================================
-
+    /// <summary>
+    /// A ConstructorBinder encapsulates information about one or more managed
+    /// constructors, and is responsible for selecting the right constructor
+    /// given a set of Python arguments. This is slightly different than the
+    /// standard MethodBinder because of a difference in invoking constructors
+    /// using reflection (which is seems to be a CLR bug).
+    /// </summary>
     internal class ConstructorBinder : MethodBinder
     {
-        private Type _containingType = null;
+        private Type _containingType;
 
-        internal ConstructorBinder(Type containingType) : base()
+        internal ConstructorBinder(Type containingType)
         {
             _containingType = containingType;
         }
 
-        //====================================================================
-        // Constructors get invoked when an instance of a wrapped managed
-        // class or a subclass of a managed class is created. This differs
-        // from the MethodBinder implementation in that we return the raw
-        // result of the constructor rather than wrapping it as a Python
-        // object - the reason is that only the caller knows the correct
-        // Python type to use when wrapping the result (may be a subclass).
-        //====================================================================
-
+        /// <summary>
+        /// Constructors get invoked when an instance of a wrapped managed
+        /// class or a subclass of a managed class is created. This differs
+        /// from the MethodBinder implementation in that we return the raw
+        /// result of the constructor rather than wrapping it as a Python
+        /// object - the reason is that only the caller knows the correct
+        /// Python type to use when wrapping the result (may be a subclass).
+        /// </summary>
         internal object InvokeRaw(IntPtr inst, IntPtr args, IntPtr kw)
         {
-            return this.InvokeRaw(inst, args, kw, null);
+            return InvokeRaw(inst, args, kw, null);
         }
 
         /// <summary>
@@ -49,10 +47,9 @@ namespace Python.Runtime
         /// Binding binding = this.Bind(inst, args, kw, info);
         /// to take advantage of Bind()'s ability to use a single MethodBase (CI or MI).
         /// </remarks>
-        internal object InvokeRaw(IntPtr inst, IntPtr args, IntPtr kw,
-            MethodBase info)
+        internal object InvokeRaw(IntPtr inst, IntPtr args, IntPtr kw, MethodBase info)
         {
-            Object result;
+            object result;
 
             if (_containingType.IsValueType && !_containingType.IsPrimitive &&
                 !_containingType.IsEnum && _containingType != typeof(decimal) &&
@@ -79,7 +76,7 @@ namespace Python.Runtime
                 return result;
             }
 
-            Binding binding = this.Bind(inst, args, kw, info);
+            Binding binding = Bind(inst, args, kw, info);
 
             if (binding == null)
             {
@@ -91,20 +88,18 @@ namespace Python.Runtime
                 // any extra args are intended for the subclass' __init__.
 
                 IntPtr eargs = Runtime.PyTuple_New(0);
-                binding = this.Bind(inst, eargs, kw);
+                binding = Bind(inst, eargs, kw);
                 Runtime.XDecref(eargs);
 
                 if (binding == null)
                 {
-                    Exceptions.SetError(Exceptions.TypeError,
-                        "no constructor matches given arguments"
-                        );
+                    Exceptions.SetError(Exceptions.TypeError, "no constructor matches given arguments");
                     return null;
                 }
             }
 
             // Fire the selected ctor and catch errors...
-            ConstructorInfo ci = (ConstructorInfo)binding.info;
+            var ci = (ConstructorInfo)binding.info;
             // Object construction is presumed to be non-blocking and fast
             // enough that we shouldn't really need to release the GIL.
             try
@@ -123,4 +118,4 @@ namespace Python.Runtime
             return result;
         }
     }
-}
\ No newline at end of file
+}
