@@ -4,13 +4,12 @@ using System.Reflection;
 
 namespace Python.Runtime
 {
-    //========================================================================
-    // A MethodBinder encapsulates information about a (possibly overloaded)
-    // managed method, and is responsible for selecting the right method given
-    // a set of Python arguments. This is also used as a base class for the
-    // ConstructorBinder, a minor variation used to invoke constructors.
-    //========================================================================
-
+    /// <summary>
+    /// A MethodBinder encapsulates information about a (possibly overloaded)
+    /// managed method, and is responsible for selecting the right method given
+    /// a set of Python arguments. This is also used as a base class for the
+    /// ConstructorBinder, a minor variation used to invoke constructors.
+    /// </summary>
     internal class MethodBinder
     {
         public ArrayList list;
@@ -20,30 +19,28 @@ namespace Python.Runtime
 
         internal MethodBinder()
         {
-            this.list = new ArrayList();
+            list = new ArrayList();
         }
 
-        internal MethodBinder(MethodInfo mi) : base()
+        internal MethodBinder(MethodInfo mi)
         {
-            this.list = new ArrayList();
-            this.list.Add(mi);
+            list = new ArrayList { mi };
         }
 
         public int Count
         {
-            get { return this.list.Count; }
+            get { return list.Count; }
         }
 
         internal void AddMethod(MethodBase m)
         {
-            this.list.Add(m);
+            list.Add(m);
         }
 
-        //====================================================================
-        // Given a sequence of MethodInfo and a sequence of types, return the
-        // MethodInfo that matches the signature represented by those types.
-        //====================================================================
-
+        /// <summary>
+        /// Given a sequence of MethodInfo and a sequence of types, return the
+        /// MethodInfo that matches the signature represented by those types.
+        /// </summary>
         internal static MethodInfo MatchSignature(MethodInfo[] mi, Type[] tp)
         {
             if (tp == null)
@@ -51,33 +48,32 @@ namespace Python.Runtime
                 return null;
             }
             int count = tp.Length;
-            for (int i = 0; i < mi.Length; i++)
+            foreach (MethodInfo t in mi)
             {
-                ParameterInfo[] pi = mi[i].GetParameters();
+                ParameterInfo[] pi = t.GetParameters();
                 if (pi.Length != count)
                 {
                     continue;
                 }
-                for (int n = 0; n < pi.Length; n++)
+                for (var n = 0; n < pi.Length; n++)
                 {
                     if (tp[n] != pi[n].ParameterType)
                     {
                         break;
                     }
-                    if (n == (pi.Length - 1))
+                    if (n == pi.Length - 1)
                     {
-                        return mi[i];
+                        return t;
                     }
                 }
             }
             return null;
         }
 
-        //====================================================================
-        // Given a sequence of MethodInfo and a sequence of type parameters,
-        // return the MethodInfo that represents the matching closed generic.
-        //====================================================================
-
+        /// <summary>
+        /// Given a sequence of MethodInfo and a sequence of type parameters,
+        /// return the MethodInfo that represents the matching closed generic.
+        /// </summary>
         internal static MethodInfo MatchParameters(MethodInfo[] mi, Type[] tp)
         {
             if (tp == null)
@@ -85,63 +81,63 @@ namespace Python.Runtime
                 return null;
             }
             int count = tp.Length;
-            for (int i = 0; i < mi.Length; i++)
+            foreach (MethodInfo t in mi)
             {
-                if (!mi[i].IsGenericMethodDefinition)
+                if (!t.IsGenericMethodDefinition)
                 {
                     continue;
                 }
-                Type[] args = mi[i].GetGenericArguments();
+                Type[] args = t.GetGenericArguments();
                 if (args.Length != count)
                 {
                     continue;
                 }
-                return mi[i].MakeGenericMethod(tp);
+                return t.MakeGenericMethod(tp);
             }
             return null;
         }
 
 
-        //====================================================================
-        // Given a sequence of MethodInfo and two sequences of type parameters,
-        // return the MethodInfo that matches the signature and the closed generic.
-        //====================================================================
-
+        /// <summary>
+        /// Given a sequence of MethodInfo and two sequences of type parameters,
+        /// return the MethodInfo that matches the signature and the closed generic.
+        /// </summary>
         internal static MethodInfo MatchSignatureAndParameters(MethodInfo[] mi, Type[] genericTp, Type[] sigTp)
         {
-            if ((genericTp == null) || (sigTp == null))
+            if (genericTp == null || sigTp == null)
             {
                 return null;
             }
             int genericCount = genericTp.Length;
             int signatureCount = sigTp.Length;
-            for (int i = 0; i < mi.Length; i++)
+            foreach (MethodInfo t in mi)
             {
-                if (!mi[i].IsGenericMethodDefinition)
+                if (!t.IsGenericMethodDefinition)
                 {
                     continue;
                 }
-                Type[] genericArgs = mi[i].GetGenericArguments();
+                Type[] genericArgs = t.GetGenericArguments();
                 if (genericArgs.Length != genericCount)
                 {
                     continue;
                 }
-                ParameterInfo[] pi = mi[i].GetParameters();
+                ParameterInfo[] pi = t.GetParameters();
                 if (pi.Length != signatureCount)
                 {
                     continue;
                 }
-                for (int n = 0; n < pi.Length; n++)
+                for (var n = 0; n < pi.Length; n++)
                 {
                     if (sigTp[n] != pi[n].ParameterType)
                     {
                         break;
                     }
-                    if (n == (pi.Length - 1))
+                    if (n == pi.Length - 1)
                     {
-                        MethodInfo match = mi[i];
+                        MethodInfo match = t;
                         if (match.IsGenericMethodDefinition)
                         {
+                            // FIXME: typeArgs not used
                             Type[] typeArgs = match.GetGenericArguments();
                             return match.MakeGenericMethod(genericTp);
                         }
@@ -153,12 +149,11 @@ namespace Python.Runtime
         }
 
 
-        //====================================================================
-        // Return the array of MethodInfo for this method. The result array
-        // is arranged in order of precendence (done lazily to avoid doing it
-        // at all for methods that are never called).
-        //====================================================================
-
+        /// <summary>
+        /// Return the array of MethodInfo for this method. The result array
+        /// is arranged in order of precedence (done lazily to avoid doing it
+        /// at all for methods that are never called).
+        /// </summary>
         internal MethodBase[] GetMethods()
         {
             if (!init)
@@ -171,19 +166,22 @@ namespace Python.Runtime
             return methods;
         }
 
-        //====================================================================
-        // Precedence algorithm largely lifted from jython - the concerns are
-        // generally the same so we'll start w/this and tweak as necessary.
-        //====================================================================
-
+        /// <summary>
+        /// Precedence algorithm largely lifted from Jython - the concerns are
+        /// generally the same so we'll start with this and tweak as necessary.
+        /// </summary>
+        /// <remarks>
+        /// Based from Jython `org.python.core.ReflectedArgs.precedence`
+        /// See: https://github.com/jythontools/jython/blob/master/src/org/python/core/ReflectedArgs.java#L192
+        /// </remarks>
         internal static int GetPrecedence(MethodBase mi)
         {
             ParameterInfo[] pi = mi.GetParameters();
             int val = mi.IsStatic ? 3000 : 0;
             int num = pi.Length;
 
-            val += (mi.IsGenericMethod ? 1 : 0);
-            for (int i = 0; i < num; i++)
+            val += mi.IsGenericMethod ? 1 : 0;
+            for (var i = 0; i < num; i++)
             {
                 val += ArgPrecedence(pi[i].ParameterType);
             }
@@ -191,73 +189,103 @@ namespace Python.Runtime
             return val;
         }
 
-        //====================================================================
-        // Return a precedence value for a particular Type object.
-        //====================================================================
-
+        /// <summary>
+        /// Return a precedence value for a particular Type object.
+        /// </summary>
         internal static int ArgPrecedence(Type t)
         {
-            Type objectType = typeof(Object);
-            if (t == objectType) return 3000;
+            Type objectType = typeof(object);
+            if (t == objectType)
+            {
+                return 3000;
+            }
 
             TypeCode tc = Type.GetTypeCode(t);
-            if (tc == TypeCode.Object) return 1;
-            if (tc == TypeCode.UInt64) return 10;
-            if (tc == TypeCode.UInt32) return 11;
-            if (tc == TypeCode.UInt16) return 12;
-            if (tc == TypeCode.Int64) return 13;
-            if (tc == TypeCode.Int32) return 14;
-            if (tc == TypeCode.Int16) return 15;
-            if (tc == TypeCode.Char) return 16;
-            if (tc == TypeCode.SByte) return 17;
-            if (tc == TypeCode.Byte) return 18;
-            if (tc == TypeCode.Single) return 20;
-            if (tc == TypeCode.Double) return 21;
-            if (tc == TypeCode.String) return 30;
-            if (tc == TypeCode.Boolean) return 40;
+            // TODO: Clean up
+            switch (tc)
+            {
+                case TypeCode.Object:
+                    return 1;
+
+                case TypeCode.UInt64:
+                    return 10;
+
+                case TypeCode.UInt32:
+                    return 11;
+
+                case TypeCode.UInt16:
+                    return 12;
+
+                case TypeCode.Int64:
+                    return 13;
+
+                case TypeCode.Int32:
+                    return 14;
+
+                case TypeCode.Int16:
+                    return 15;
+
+                case TypeCode.Char:
+                    return 16;
+
+                case TypeCode.SByte:
+                    return 17;
+
+                case TypeCode.Byte:
+                    return 18;
+
+                case TypeCode.Single:
+                    return 20;
+
+                case TypeCode.Double:
+                    return 21;
+
+                case TypeCode.String:
+                    return 30;
+
+                case TypeCode.Boolean:
+                    return 40;
+            }
 
             if (t.IsArray)
             {
                 Type e = t.GetElementType();
                 if (e == objectType)
+                {
                     return 2500;
+                }
                 return 100 + ArgPrecedence(e);
             }
 
             return 2000;
         }
 
-        //====================================================================
-        // Bind the given Python instance and arguments to a particular method
-        // overload and return a structure that contains the converted Python
-        // instance, converted arguments and the correct method to call.
-        //====================================================================
-
+        /// <summary>
+        /// Bind the given Python instance and arguments to a particular method
+        /// overload and return a structure that contains the converted Python
+        /// instance, converted arguments and the correct method to call.
+        /// </summary>
         internal Binding Bind(IntPtr inst, IntPtr args, IntPtr kw)
         {
-            return this.Bind(inst, args, kw, null, null);
+            return Bind(inst, args, kw, null, null);
         }
 
-        internal Binding Bind(IntPtr inst, IntPtr args, IntPtr kw,
-            MethodBase info)
+        internal Binding Bind(IntPtr inst, IntPtr args, IntPtr kw, MethodBase info)
         {
-            return this.Bind(inst, args, kw, info, null);
+            return Bind(inst, args, kw, info, null);
         }
 
-        internal Binding Bind(IntPtr inst, IntPtr args, IntPtr kw,
-            MethodBase info, MethodInfo[] methodinfo)
+        internal Binding Bind(IntPtr inst, IntPtr args, IntPtr kw, MethodBase info, MethodInfo[] methodinfo)
         {
             // loop to find match, return invoker w/ or /wo error
             MethodBase[] _methods = null;
             int pynargs = Runtime.PyTuple_Size(args);
             object arg;
-            bool isGeneric = false;
+            var isGeneric = false;
             ArrayList defaultArgList = null;
             if (info != null)
             {
-                _methods = (MethodBase[])Array.CreateInstance(
-                    typeof(MethodBase), 1
-                    );
+                _methods = new MethodBase[1];
                 _methods.SetValue(info, 0);
             }
             else
@@ -265,19 +293,18 @@ namespace Python.Runtime
                 _methods = GetMethods();
             }
             Type clrtype;
-            for (int i = 0; i < _methods.Length; i++)
+            // TODO: Clean up
+            foreach (MethodBase mi in _methods)
             {
-                MethodBase mi = _methods[i];
-
                 if (mi.IsGenericMethod)
                 {
                     isGeneric = true;
                 }
                 ParameterInfo[] pi = mi.GetParameters();
                 int clrnargs = pi.Length;
-                bool match = false;
+                var match = false;
                 int arrayStart = -1;
-                int outs = 0;
+                var outs = 0;
 
                 if (pynargs == clrnargs)
                 {
@@ -290,24 +317,28 @@ namespace Python.Runtime
                     for (int v = pynargs; v < clrnargs; v++)
                     {
                         if (pi[v].DefaultValue == DBNull.Value)
+                        {
                             match = false;
+                        }
                         else
-                            defaultArgList.Add((object)pi[v].DefaultValue);
+                        {
+                            defaultArgList.Add(pi[v].DefaultValue);
+                        }
                     }
                 }
-                else if ((pynargs > clrnargs) && (clrnargs > 0) &&
+                else if (pynargs > clrnargs && clrnargs > 0 &&
                          Attribute.IsDefined(pi[clrnargs - 1], typeof(ParamArrayAttribute)))
                 {
-                    // This is a spam(params object[] egg) style method
+                    // This is a `foo(params object[] bar)` style method
                     match = true;
                     arrayStart = clrnargs - 1;
                 }
 
                 if (match)
                 {
-                    Object[] margs = new Object[clrnargs];
+                    var margs = new object[clrnargs];
 
-                    for (int n = 0; n < clrnargs; n++)
+                    for (var n = 0; n < clrnargs; n++)
                     {
                         IntPtr op;
                         if (n < pynargs)
@@ -343,8 +374,8 @@ namespace Python.Runtime
 
                             if (clrtype != null)
                             {
-                                bool typematch = false;
-                                if (pi[n].ParameterType != clrtype)
+                                var typematch = false;
+                                if ((pi[n].ParameterType != typeof(object)) && (pi[n].ParameterType != clrtype))
                                 {
                                     IntPtr pytype = Converter.GetPythonTypeByAlias(pi[n].ParameterType);
                                     pyoptype = Runtime.PyObject_Type(op);
@@ -412,7 +443,9 @@ namespace Python.Runtime
                         else
                         {
                             if (defaultArgList != null)
+                            {
                                 margs[n] = defaultArgList[n - pynargs];
+                            }
                         }
                     }
 
@@ -421,13 +454,13 @@ namespace Python.Runtime
                         continue;
                     }
 
-                    Object target = null;
-                    if ((!mi.IsStatic) && (inst != IntPtr.Zero))
+                    object target = null;
+                    if (!mi.IsStatic && inst != IntPtr.Zero)
                     {
                         //CLRObject co = (CLRObject)ManagedType.GetManagedObject(inst);
                         // InvalidCastException: Unable to cast object of type
                         // 'Python.Runtime.ClassObject' to type 'Python.Runtime.CLRObject'
-                        CLRObject co = ManagedType.GetManagedObject(inst) as CLRObject;
+                        var co = ManagedType.GetManagedObject(inst) as CLRObject;
 
                         // Sanity check: this ensures a graceful exit if someone does
                         // something intentionally wrong like call a non-static method
@@ -447,10 +480,10 @@ namespace Python.Runtime
             // is a generic method and info is null. That happens when a generic
             // method was not called using the [] syntax. Let's introspect the
             // type of the arguments and use it to construct the correct method.
-            if (isGeneric && (info == null) && (methodinfo != null))
+            if (isGeneric && info == null && methodinfo != null)
             {
                 Type[] types = Runtime.PythonArgsToTypeArray(args, true);
-                MethodInfo mi = MethodBinder.MatchParameters(methodinfo, types);
+                MethodInfo mi = MatchParameters(methodinfo, types);
                 return Bind(inst, args, kw, mi, null);
             }
             return null;
@@ -458,27 +491,23 @@ namespace Python.Runtime
 
         internal virtual IntPtr Invoke(IntPtr inst, IntPtr args, IntPtr kw)
         {
-            return this.Invoke(inst, args, kw, null, null);
+            return Invoke(inst, args, kw, null, null);
         }
 
-        internal virtual IntPtr Invoke(IntPtr inst, IntPtr args, IntPtr kw,
-            MethodBase info)
+        internal virtual IntPtr Invoke(IntPtr inst, IntPtr args, IntPtr kw, MethodBase info)
         {
-            return this.Invoke(inst, args, kw, info, null);
+            return Invoke(inst, args, kw, info, null);
         }
 
-        internal virtual IntPtr Invoke(IntPtr inst, IntPtr args, IntPtr kw,
-            MethodBase info, MethodInfo[] methodinfo)
+        internal virtual IntPtr Invoke(IntPtr inst, IntPtr args, IntPtr kw, MethodBase info, MethodInfo[] methodinfo)
         {
-            Binding binding = this.Bind(inst, args, kw, info, methodinfo);
-            Object result;
+            Binding binding = Bind(inst, args, kw, info, methodinfo);
+            object result;
             IntPtr ts = IntPtr.Zero;
 
             if (binding == null)
             {
-                Exceptions.SetError(Exceptions.TypeError,
-                    "No method matches given arguments"
-                    );
+                Exceptions.SetError(Exceptions.TypeError, "No method matches given arguments");
                 return IntPtr.Zero;
             }
 
@@ -489,11 +518,7 @@ namespace Python.Runtime
 
             try
             {
-                result = binding.info.Invoke(binding.inst,
-                    BindingFlags.Default,
-                    null,
-                    binding.args,
-                    null);
+                result = binding.info.Invoke(binding.inst, BindingFlags.Default, null, binding.args, null);
             }
             catch (Exception e)
             {
@@ -520,9 +545,9 @@ namespace Python.Runtime
             // we return the out parameter as the result to Python (for
             // code compatibility with ironpython).
 
-            MethodInfo mi = (MethodInfo)binding.info;
+            var mi = (MethodInfo)binding.info;
 
-            if ((binding.outs == 1) && (mi.ReturnType == typeof(void)))
+            if (binding.outs == 1 && mi.ReturnType == typeof(void))
             {
             }
 
@@ -530,14 +555,14 @@ namespace Python.Runtime
             {
                 ParameterInfo[] pi = mi.GetParameters();
                 int c = pi.Length;
-                int n = 0;
+                var n = 0;
 
                 IntPtr t = Runtime.PyTuple_New(binding.outs + 1);
                 IntPtr v = Converter.ToPython(result, mi.ReturnType);
                 Runtime.PyTuple_SetItem(t, n, v);
                 n++;
 
-                for (int i = 0; i < c; i++)
+                for (var i = 0; i < c; i++)
                 {
                     Type pt = pi[i].ParameterType;
                     if (pi[i].IsOut || pt.IsByRef)
@@ -548,7 +573,7 @@ namespace Python.Runtime
                     }
                 }
 
-                if ((binding.outs == 1) && (mi.ReturnType == typeof(void)))
+                if (binding.outs == 1 && mi.ReturnType == typeof(void))
                 {
                     v = Runtime.PyTuple_GetItem(t, 1);
                     Runtime.XIncref(v);
@@ -564,38 +589,41 @@ namespace Python.Runtime
     }
 
 
-    //========================================================================
-    // Utility class to sort method info by parameter type precedence.
-    //========================================================================
-
+    /// <summary>
+    /// Utility class to sort method info by parameter type precedence.
+    /// </summary>
     internal class MethodSorter : IComparer
     {
-        int IComparer.Compare(Object m1, Object m2)
+        int IComparer.Compare(object m1, object m2)
         {
             int p1 = MethodBinder.GetPrecedence((MethodBase)m1);
             int p2 = MethodBinder.GetPrecedence((MethodBase)m2);
-            if (p1 < p2) return -1;
-            if (p1 > p2) return 1;
+            if (p1 < p2)
+            {
+                return -1;
+            }
+            if (p1 > p2)
+            {
+                return 1;
+            }
             return 0;
         }
     }
 
 
-    //========================================================================
-    // A Binding is a utility instance that bundles together a MethodInfo
-    // representing a method to call, a (possibly null) target instance for
-    // the call, and the arguments for the call (all as managed values).
-    //========================================================================
-
+    /// <summary>
+    /// A Binding is a utility instance that bundles together a MethodInfo
+    /// representing a method to call, a (possibly null) target instance for
+    /// the call, and the arguments for the call (all as managed values).
+    /// </summary>
     internal class Binding
     {
         public MethodBase info;
-        public Object[] args;
-        public Object inst;
+        public object[] args;
+        public object inst;
         public int outs;
 
-        internal Binding(MethodBase info, Object inst, Object[] args,
-            int outs)
+        internal Binding(MethodBase info, object inst, object[] args, int outs)
         {
             this.info = info;
             this.inst = inst;
@@ -603,4 +631,4 @@ namespace Python.Runtime
             this.outs = outs;
         }
     }
-}
\ No newline at end of file
+}
