@@ -1,27 +1,25 @@
 using System;
-using System.Collections.Specialized;
-using System.Runtime.InteropServices;
 using System.Collections.Generic;
-using System.Collections;
+using System.IO;
 using System.Reflection;
+using System.Runtime.InteropServices;
 
 namespace Python.Runtime
 {
-    //========================================================================
-    // Implements a Python type that provides access to CLR namespaces. The
-    // type behaves like a Python module, and can contain other sub-modules.
-    //========================================================================
-
+    /// <summary>
+    /// Implements a Python type that provides access to CLR namespaces. The
+    /// type behaves like a Python module, and can contain other sub-modules.
+    /// </summary>
     internal class ModuleObject : ExtensionType
     {
-        Dictionary<string, ManagedType> cache;
+        private Dictionary<string, ManagedType> cache;
         internal string moduleName;
         internal IntPtr dict;
         protected string _namespace;
 
-        public ModuleObject(string name) : base()
+        public ModuleObject(string name)
         {
-            if (name == String.Empty)
+            if (name == string.Empty)
             {
                 throw new ArgumentException("Name must not be empty!");
             }
@@ -31,8 +29,8 @@ namespace Python.Runtime
 
             // Use the filename from any of the assemblies just so there's something for
             // anything that expects __file__ to be set.
-            string filename = "unknown";
-            string docstring = "Namespace containing types from the following assemblies:\n\n";
+            var filename = "unknown";
+            var docstring = "Namespace containing types from the following assemblies:\n\n";
             foreach (Assembly a in AssemblyManager.GetAssemblies(name))
             {
                 if (!a.IsDynamic && a.Location != null)
@@ -46,7 +44,7 @@ namespace Python.Runtime
             IntPtr pyname = Runtime.PyString_FromString(moduleName);
             IntPtr pyfilename = Runtime.PyString_FromString(filename);
             IntPtr pydocstring = Runtime.PyString_FromString(docstring);
-            IntPtr pycls = TypeManager.GetTypeHandle(this.GetType());
+            IntPtr pycls = TypeManager.GetTypeHandle(GetType());
             Runtime.PyDict_SetItemString(dict, "__name__", pyname);
             Runtime.PyDict_SetItemString(dict, "__file__", pyfilename);
             Runtime.PyDict_SetItemString(dict, "__doc__", pydocstring);
@@ -55,23 +53,22 @@ namespace Python.Runtime
             Runtime.XDecref(pyfilename);
             Runtime.XDecref(pydocstring);
 
-            Marshal.WriteIntPtr(this.pyHandle, ObjectOffset.DictOffset(this.pyHandle), dict);
+            Marshal.WriteIntPtr(pyHandle, ObjectOffset.DictOffset(pyHandle), dict);
 
             InitializeModuleMembers();
         }
 
 
-        //===================================================================
-        // Returns a ClassBase object representing a type that appears in
-        // this module's namespace or a ModuleObject representing a child
-        // namespace (or null if the name is not found). This method does
-        // not increment the Python refcount of the returned object.
-        //===================================================================
-
+        /// <summary>
+        /// Returns a ClassBase object representing a type that appears in
+        /// this module's namespace or a ModuleObject representing a child
+        /// namespace (or null if the name is not found). This method does
+        /// not increment the Python refcount of the returned object.
+        /// </summary>
         public ManagedType GetAttribute(string name, bool guess)
         {
             ManagedType cached = null;
-            this.cache.TryGetValue(name, out cached);
+            cache.TryGetValue(name, out cached);
             if (cached != null)
             {
                 return cached;
@@ -91,25 +88,23 @@ namespace Python.Runtime
             //    return null;
             //}
 
-            string qname = (_namespace == String.Empty)
+            string qname = _namespace == string.Empty
                 ? name
                 : _namespace + "." + name;
 
             // If the fully-qualified name of the requested attribute is
             // a namespace exported by a currently loaded assembly, return
             // a new ModuleObject representing that namespace.
-
             if (AssemblyManager.IsValidNamespace(qname))
             {
                 m = new ModuleObject(qname);
                 StoreAttribute(name, m);
-                return (ManagedType)m;
+                return m;
             }
 
             // Look for a type in the current namespace. Note that this
             // includes types, delegates, enums, interfaces and structs.
             // Only public namespace members are exposed to Python.
-
             type = AssemblyManager.LookupType(qname);
             if (type != null)
             {
@@ -119,7 +114,7 @@ namespace Python.Runtime
                 }
                 c = ClassManager.GetClass(type);
                 StoreAttribute(name, c);
-                return (ManagedType)c;
+                return c;
             }
 
             // This is a little repetitive, but it ensures that the right
@@ -133,7 +128,7 @@ namespace Python.Runtime
                 {
                     m = new ModuleObject(qname);
                     StoreAttribute(name, m);
-                    return (ManagedType)m;
+                    return m;
                 }
 
                 type = AssemblyManager.LookupType(qname);
@@ -145,7 +140,7 @@ namespace Python.Runtime
                     }
                     c = ClassManager.GetClass(type);
                     StoreAttribute(name, c);
-                    return (ManagedType)c;
+                    return c;
                 }
             }
 
@@ -156,11 +151,9 @@ namespace Python.Runtime
             // future assembly load could contribute a non-generic type to
             // the current namespace with the given basename, but unlikely
             // enough to complicate the implementation for now.
-
             if (guess)
             {
-                string gname = GenericUtil.GenericNameForBaseName(
-                    _namespace, name);
+                string gname = GenericUtil.GenericNameForBaseName(_namespace, name);
                 if (gname != null)
                 {
                     ManagedType o = GetAttribute(gname, false);
@@ -176,10 +169,9 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Stores an attribute in the instance dict for future lookups.
-        //===================================================================
-
+        /// <summary>
+        /// Stores an attribute in the instance dict for future lookups.
+        /// </summary>
         private void StoreAttribute(string name, ManagedType ob)
         {
             Runtime.PyDict_SetItemString(dict, name, ob.pyHandle);
@@ -187,21 +179,20 @@ namespace Python.Runtime
         }
 
 
-        //===================================================================
-        // Preloads all currently-known names for the module namespace. This
-        // can be called multiple times, to add names from assemblies that
-        // may have been loaded since the last call to the method.
-        //===================================================================
-
+        /// <summary>
+        /// Preloads all currently-known names for the module namespace. This
+        /// can be called multiple times, to add names from assemblies that
+        /// may have been loaded since the last call to the method.
+        /// </summary>
         public void LoadNames()
         {
             ManagedType m = null;
             foreach (string name in AssemblyManager.GetNames(_namespace))
             {
-                this.cache.TryGetValue(name, out m);
+                cache.TryGetValue(name, out m);
                 if (m == null)
                 {
-                    ManagedType attr = this.GetAttribute(name, true);
+                    ManagedType attr = GetAttribute(name, true);
                 }
             }
         }
@@ -214,38 +205,36 @@ namespace Python.Runtime
             Type funcmarker = typeof(ModuleFunctionAttribute);
             Type propmarker = typeof(ModulePropertyAttribute);
             Type ftmarker = typeof(ForbidPythonThreadsAttribute);
-            Type type = this.GetType();
+            Type type = GetType();
 
             BindingFlags flags = BindingFlags.Public | BindingFlags.Static;
 
             while (type != null)
             {
                 MethodInfo[] methods = type.GetMethods(flags);
-                for (int i = 0; i < methods.Length; i++)
+                foreach (MethodInfo method in methods)
                 {
-                    MethodInfo method = methods[i];
                     object[] attrs = method.GetCustomAttributes(funcmarker, false);
                     object[] forbid = method.GetCustomAttributes(ftmarker, false);
-                    bool allow_threads = (forbid.Length == 0);
+                    bool allow_threads = forbid.Length == 0;
                     if (attrs.Length > 0)
                     {
                         string name = method.Name;
-                        MethodInfo[] mi = new MethodInfo[1];
+                        var mi = new MethodInfo[1];
                         mi[0] = method;
-                        ModuleFunctionObject m = new ModuleFunctionObject(type, name, mi, allow_threads);
+                        var m = new ModuleFunctionObject(type, name, mi, allow_threads);
                         StoreAttribute(name, m);
                     }
                 }
 
                 PropertyInfo[] properties = type.GetProperties();
-                for (int i = 0; i < properties.Length; i++)
+                foreach (PropertyInfo property in properties)
                 {
-                    PropertyInfo property = properties[i];
                     object[] attrs = property.GetCustomAttributes(propmarker, false);
                     if (attrs.Length > 0)
                     {
                         string name = property.Name;
-                        ModulePropertyObject p = new ModulePropertyObject(property);
+                        var p = new ModulePropertyObject(property);
                         StoreAttribute(name, p);
                     }
                 }
@@ -254,16 +243,15 @@ namespace Python.Runtime
         }
 
 
-        //====================================================================
-        // ModuleObject __getattribute__ implementation. Module attributes
-        // are always either classes or sub-modules representing subordinate
-        // namespaces. CLR modules implement a lazy pattern - the sub-modules
-        // and classes are created when accessed and cached for future use.
-        //====================================================================
-
+        /// <summary>
+        /// ModuleObject __getattribute__ implementation. Module attributes
+        /// are always either classes or sub-modules representing subordinate
+        /// namespaces. CLR modules implement a lazy pattern - the sub-modules
+        /// and classes are created when accessed and cached for future use.
+        /// </summary>
         public static IntPtr tp_getattro(IntPtr ob, IntPtr key)
         {
-            ModuleObject self = (ModuleObject)GetManagedObject(ob);
+            var self = (ModuleObject)GetManagedObject(ob);
 
             if (!Runtime.PyString_Check(key))
             {
@@ -297,15 +285,13 @@ namespace Python.Runtime
             return attr.pyHandle;
         }
 
-        //====================================================================
-        // ModuleObject __repr__ implementation.
-        //====================================================================
-
+        /// <summary>
+        /// ModuleObject __repr__ implementation.
+        /// </summary>
         public static IntPtr tp_repr(IntPtr ob)
         {
-            ModuleObject self = (ModuleObject)GetManagedObject(ob);
-            string s = String.Format("<module '{0}'>", self.moduleName);
-            return Runtime.PyString_FromString(s);
+            var self = (ModuleObject)GetManagedObject(ob);
+            return Runtime.PyString_FromString($"<module '{self.moduleName}'>");
         }
     }
 
@@ -325,7 +311,7 @@ namespace Python.Runtime
 
         public CLRModule() : base("clr")
         {
-            _namespace = String.Empty;
+            _namespace = string.Empty;
 
             // This hackery is required in order to allow a plain Python to
             // import the managed runtime via the CLR bootstrapper module.
@@ -333,7 +319,7 @@ namespace Python.Runtime
             // import requires the module to pass PyModule_Check. :(
             if (!hacked)
             {
-                IntPtr type = this.tpHandle;
+                IntPtr type = tpHandle;
                 IntPtr mro = Marshal.ReadIntPtr(type, TypeOffset.tp_mro);
                 IntPtr ext = Runtime.ExtendTuple(mro, Runtime.PyModuleType);
                 Marshal.WriteIntPtr(type, TypeOffset.tp_mro, ext);
@@ -364,34 +350,34 @@ namespace Python.Runtime
             }
         }
 
-        [ModuleFunctionAttribute()]
+        [ModuleFunction]
         public static bool getPreload()
         {
             return preload;
         }
 
-        [ModuleFunctionAttribute()]
+        [ModuleFunction]
         public static void setPreload(bool preloadFlag)
         {
             preload = preloadFlag;
         }
 
-        //[ModulePropertyAttribute]
+        //[ModuleProperty]
         public static bool SuppressDocs
         {
             get { return _SuppressDocs; }
             set { _SuppressDocs = value; }
         }
 
-        //[ModulePropertyAttribute]
+        //[ModuleProperty]
         public static bool SuppressOverloads
         {
             get { return _SuppressOverloads; }
             set { _SuppressOverloads = value; }
         }
 
-        [ModuleFunctionAttribute()]
-        [ForbidPythonThreadsAttribute()]
+        [ModuleFunction]
+        [ForbidPythonThreads]
         public static Assembly AddReference(string name)
         {
             AssemblyManager.UpdatePath();
@@ -411,40 +397,43 @@ namespace Python.Runtime
             }
             if (assembly == null)
             {
-                string msg = String.Format("Unable to find assembly '{0}'.", name);
-                throw new System.IO.FileNotFoundException(msg);
+                throw new FileNotFoundException($"Unable to find assembly '{name}'.");
             }
 
             return assembly;
         }
 
-        [ModuleFunctionAttribute()]
-        [ForbidPythonThreadsAttribute()]
+        [ModuleFunction]
+        [ForbidPythonThreads]
         public static string FindAssembly(string name)
         {
             AssemblyManager.UpdatePath();
             return AssemblyManager.FindAssembly(name);
         }
 
-        [ModuleFunctionAttribute()]
-        public static String[] ListAssemblies(bool verbose)
+        [ModuleFunction]
+        public static string[] ListAssemblies(bool verbose)
         {
             AssemblyName[] assnames = AssemblyManager.ListAssemblies();
-            String[] names = new String[assnames.Length];
-            for (int i = 0; i < assnames.Length; i++)
+            var names = new string[assnames.Length];
+            for (var i = 0; i < assnames.Length; i++)
             {
                 if (verbose)
+                {
                     names[i] = assnames[i].FullName;
+                }
                 else
+                {
                     names[i] = assnames[i].Name;
+                }
             }
             return names;
         }
 
-        [ModuleFunctionAttribute()]
+        [ModuleFunction]
         public static int _AtExit()
         {
             return Runtime.AtExit();
         }
     }
-}
\ No newline at end of file
+}
