@@ -1,19 +1,42 @@
 using System;
+using System.Collections.Generic;
 using System.IO;
-using System.Threading;
+using System.Linq;
 using System.Reflection;
+using System.Runtime.InteropServices;
 
 namespace Python.Runtime
 {
     /// <summary>
     /// This class provides the public interface of the Python runtime.
     /// </summary>
-    public class PythonEngine
+    public class PythonEngine : IDisposable
     {
         private static DelegateManager delegateManager;
         private static bool initialized;
+        private static IntPtr _pythonHome = IntPtr.Zero;
+        private static IntPtr _programName = IntPtr.Zero;
+        private static IntPtr _pythonPath = IntPtr.Zero;
 
-        #region Properties
+        public PythonEngine()
+        {
+            Initialize();
+        }
+
+        public PythonEngine(params string[] args)
+        {
+            Initialize(args);
+        }
+
+        public PythonEngine(IEnumerable<string> args)
+        {
+            Initialize(args);
+        }
+
+        public void Dispose()
+        {
+            Shutdown();
+        }
 
         public static bool IsInitialized
         {
@@ -37,62 +60,74 @@ namespace Python.Runtime
         {
             get
             {
-                string result = Runtime.Py_GetProgramName();
-                if (result == null)
-                {
-                    return "";
-                }
-                return result;
+                IntPtr p = Runtime.Py_GetProgramName();
+                return UcsMarshaler.PtrToPy3UnicodePy2String(p) ?? "";
+            }
+            set
+            {
+                Marshal.FreeHGlobal(_programName);
+                _programName = UcsMarshaler.Py3UnicodePy2StringtoPtr(value);
+                Runtime.Py_SetProgramName(_programName);
             }
-            set { Runtime.Py_SetProgramName(value); }
         }
 
         public static string PythonHome
         {
             get
             {
-                string result = Runtime.Py_GetPythonHome();
-                if (result == null)
-                {
-                    return "";
-                }
-                return result;
+                IntPtr p = Runtime.Py_GetPythonHome();
+                return UcsMarshaler.PtrToPy3UnicodePy2String(p) ?? "";
+            }
+            set
+            {
+                Marshal.FreeHGlobal(_pythonHome);
+                _pythonHome = UcsMarshaler.Py3UnicodePy2StringtoPtr(value);
+                Runtime.Py_SetPythonHome(_pythonHome);
             }
-            set { Runtime.Py_SetPythonHome(value); }
         }
 
         public static string PythonPath
         {
             get
             {
-                string result = Runtime.Py_GetPath();
-                if (result == null)
+                IntPtr p = Runtime.Py_GetPath();
+                return UcsMarshaler.PtrToPy3UnicodePy2String(p) ?? "";
+            }
+            set
+            {
+                if (Runtime.IsPython2)
                 {
-                    return "";
+                    throw new NotSupportedException("Set PythonPath not supported on Python 2");
                 }
-                return result;
+                Marshal.FreeHGlobal(_pythonPath);
+                _pythonPath = UcsMarshaler.Py3UnicodePy2StringtoPtr(value);
+                Runtime.Py_SetPath(_pythonPath);
             }
-            set { Runtime.Py_SetPath(value); }
         }
 
         public static string Version
         {
-            get { return Runtime.Py_GetVersion(); }
+            get { return Marshal.PtrToStringAnsi(Runtime.Py_GetVersion()); }
         }
 
         public static string BuildInfo
         {
-            get { return Runtime.Py_GetBuildInfo(); }
+            get { return Marshal.PtrToStringAnsi(Runtime.Py_GetBuildInfo()); }
         }
 
         public static string Platform
         {
-            get { return Runtime.Py_GetPlatform(); }
+            get { return Marshal.PtrToStringAnsi(Runtime.Py_GetPlatform()); }
         }
 
         public static string Copyright
         {
-            get { return Runtime.Py_GetCopyright(); }
+            get { return Marshal.PtrToStringAnsi(Runtime.Py_GetCopyright()); }
+        }
+
+        public static string Compiler
+        {
+            get { return Marshal.PtrToStringAnsi(Runtime.Py_GetCompiler()); }
         }
 
         public static int RunSimpleString(string code)
@@ -100,19 +135,26 @@ namespace Python.Runtime
             return Runtime.PyRun_SimpleString(code);
         }
 
-        #endregion
+        public static void Initialize()
+        {
+            Initialize(setSysArgv: true);
+        }
+
+        public static void Initialize(bool setSysArgv = true)
+        {
+            Initialize(Enumerable.Empty<string>(), setSysArgv: setSysArgv);
+        }
 
         /// <summary>
         /// Initialize Method
         /// </summary>
-        ///
         /// <remarks>
         /// Initialize the Python runtime. It is safe to call this method
         /// more than once, though initialization will only happen on the
         /// first call. It is *not* necessary to hold the Python global
         /// interpreter lock (GIL) to call this method.
         /// </remarks>
-        public static void Initialize()
+        public static void Initialize(IEnumerable<string> args, bool setSysArgv = true)
         {
             if (!initialized)
             {
@@ -126,21 +168,24 @@ namespace Python.Runtime
                 initialized = true;
                 Exceptions.Clear();
 
+                if (setSysArgv)
+                {
+                    Py.SetArgv(args);
+                }
+
                 // register the atexit callback (this doesn't use Py_AtExit as the C atexit
                 // callbacks are called after python is fully finalized but the python ones
                 // are called while the python engine is still running).
                 string code =
                     "import atexit, clr\n" +
                     "atexit.register(clr._AtExit)\n";
-                PyObject r = PythonEngine.RunString(code);
-                if (r != null)
-                    r.Dispose();
+                PythonEngine.Exec(code);
 
                 // Load the clr.py resource into the clr module
                 IntPtr clr = Python.Runtime.ImportHook.GetCLRModule();
                 IntPtr clr_dict = Runtime.PyModule_GetDict(clr);
 
-                PyDict locals = new PyDict();
+                var locals = new PyDict();
                 try
                 {
                     IntPtr module = Runtime.PyImport_AddModule("clr._extras");
@@ -148,16 +193,13 @@ namespace Python.Runtime
                     IntPtr builtins = Runtime.PyEval_GetBuiltins();
                     Runtime.PyDict_SetItemString(module_globals, "__builtins__", builtins);
 
-                    var assembly = Assembly.GetExecutingAssembly();
+                    Assembly assembly = Assembly.GetExecutingAssembly();
                     using (Stream stream = assembly.GetManifestResourceStream("clr.py"))
-                    using (StreamReader reader = new StreamReader(stream))
+                    using (var reader = new StreamReader(stream))
                     {
                         // add the contents of clr.py to the module
                         string clr_py = reader.ReadToEnd();
-                        PyObject result = RunString(clr_py, module_globals, locals.Handle);
-                        if (null == result)
-                            throw new PythonException();
-                        result.Dispose();
+                        Exec(clr_py, module_globals, locals.Handle);
                     }
 
                     // add the imported module to the clr module, and copy the API functions
@@ -181,20 +223,20 @@ namespace Python.Runtime
             }
         }
 
-        //====================================================================
-        // A helper to perform initialization from the context of an active
-        // CPython interpreter process - this bootstraps the managed runtime
-        // when it is imported by the CLR extension module.
-        //====================================================================
+        /// <summary>
+        /// A helper to perform initialization from the context of an active
+        /// CPython interpreter process - this bootstraps the managed runtime
+        /// when it is imported by the CLR extension module.
+        /// </summary>
 #if PYTHON3
-        public static IntPtr InitExt() {
+        public static IntPtr InitExt()
 #elif PYTHON2
         public static void InitExt()
-        {
 #endif
+        {
             try
             {
-                Initialize();
+                Initialize(setSysArgv: false);
 
                 // Trickery - when the import hook is installed into an already
                 // running Python, the standard import machinery is still in
@@ -225,11 +267,7 @@ namespace Python.Runtime
                     "            exec(line)\n" +
                     "            break\n";
 
-                PyObject r = PythonEngine.RunString(code);
-                if (r != null)
-                {
-                    r.Dispose();
-                }
+                PythonEngine.Exec(code);
             }
             catch (PythonException e)
             {
@@ -247,7 +285,6 @@ namespace Python.Runtime
         /// <summary>
         /// Shutdown Method
         /// </summary>
-        ///
         /// <remarks>
         /// Shutdown and release resources held by the Python runtime. The
         /// Python runtime can no longer be used in the current process
@@ -257,6 +294,13 @@ namespace Python.Runtime
         {
             if (initialized)
             {
+                Marshal.FreeHGlobal(_pythonHome);
+                _pythonHome = IntPtr.Zero;
+                Marshal.FreeHGlobal(_programName);
+                _programName = IntPtr.Zero;
+                Marshal.FreeHGlobal(_pythonPath);
+                _pythonPath = IntPtr.Zero;
+
                 Runtime.Shutdown();
                 initialized = false;
             }
@@ -266,17 +310,14 @@ namespace Python.Runtime
         /// <summary>
         /// AcquireLock Method
         /// </summary>
-        ///
         /// <remarks>
         /// Acquire the Python global interpreter lock (GIL). Managed code
         /// *must* call this method before using any objects or calling any
         /// methods on objects in the Python.Runtime namespace. The only
         /// exception is PythonEngine.Initialize, which may be called without
         /// first calling AcquireLock.
-        ///
         /// Each call to AcquireLock must be matched by a corresponding call
         /// to ReleaseLock, passing the token obtained from AcquireLock.
-        ///
         /// For more information, see the "Extending and Embedding" section
         /// of the Python documentation on www.python.org.
         /// </remarks>
@@ -289,11 +330,9 @@ namespace Python.Runtime
         /// <summary>
         /// ReleaseLock Method
         /// </summary>
-        ///
         /// <remarks>
         /// Release the Python global interpreter lock using a token obtained
         /// from a previous call to AcquireLock.
-        ///
         /// For more information, see the "Extending and Embedding" section
         /// of the Python documentation on www.python.org.
         /// </remarks>
@@ -306,12 +345,10 @@ namespace Python.Runtime
         /// <summary>
         /// BeginAllowThreads Method
         /// </summary>
-        ///
         /// <remarks>
         /// Release the Python global interpreter lock to allow other threads
         /// to run. This is equivalent to the Py_BEGIN_ALLOW_THREADS macro
         /// provided by the C Python API.
-        ///
         /// For more information, see the "Extending and Embedding" section
         /// of the Python documentation on www.python.org.
         /// </remarks>
@@ -324,12 +361,10 @@ namespace Python.Runtime
         /// <summary>
         /// EndAllowThreads Method
         /// </summary>
-        ///
         /// <remarks>
         /// Re-aquire the Python global interpreter lock for the current
         /// thread. This is equivalent to the Py_END_ALLOW_THREADS macro
         /// provided by the C Python API.
-        ///
         /// For more information, see the "Extending and Embedding" section
         /// of the Python documentation on www.python.org.
         /// </remarks>
@@ -342,7 +377,6 @@ namespace Python.Runtime
         /// <summary>
         /// ImportModule Method
         /// </summary>
-        ///
         /// <remarks>
         /// Given a fully-qualified module or package name, import the
         /// module and return the resulting module object as a PyObject
@@ -351,10 +385,7 @@ namespace Python.Runtime
         public static PyObject ImportModule(string name)
         {
             IntPtr op = Runtime.PyImport_ImportModule(name);
-            if (op == IntPtr.Zero)
-            {
-                return null;
-            }
+            Runtime.CheckExceptionOccurred();
             return new PyObject(op);
         }
 
@@ -362,7 +393,6 @@ namespace Python.Runtime
         /// <summary>
         /// ReloadModule Method
         /// </summary>
-        ///
         /// <remarks>
         /// Given a PyObject representing a previously loaded module, reload
         /// the module.
@@ -370,10 +400,7 @@ namespace Python.Runtime
         public static PyObject ReloadModule(PyObject module)
         {
             IntPtr op = Runtime.PyImport_ReloadModule(module.Handle);
-            if (op == IntPtr.Zero)
-            {
-                throw new PythonException();
-            }
+            Runtime.CheckExceptionOccurred();
             return new PyObject(op);
         }
 
@@ -381,7 +408,6 @@ namespace Python.Runtime
         /// <summary>
         /// ModuleFromString Method
         /// </summary>
-        ///
         /// <remarks>
         /// Given a string module name and a string containing Python code,
         /// execute the code in and return a module of the given name.
@@ -389,64 +415,126 @@ namespace Python.Runtime
         public static PyObject ModuleFromString(string name, string code)
         {
             IntPtr c = Runtime.Py_CompileString(code, "none", (IntPtr)257);
-            if (c == IntPtr.Zero)
-            {
-                throw new PythonException();
-            }
+            Runtime.CheckExceptionOccurred();
             IntPtr m = Runtime.PyImport_ExecCodeModule(name, c);
-            if (m == IntPtr.Zero)
-            {
-                throw new PythonException();
-            }
+            Runtime.CheckExceptionOccurred();
             return new PyObject(m);
         }
 
 
         /// <summary>
-        /// RunString Method
+        /// Eval Method
+        /// </summary>
+        /// <remarks>
+        /// Evaluate a Python expression and returns the result.
+        /// It's a subset of Python eval function.
+        /// </remarks>
+        public static PyObject Eval(string code, IntPtr? globals = null, IntPtr? locals = null)
+        {
+            PyObject result = RunString(code, globals, locals, RunFlagType.Eval);
+            return result;
+        }
+
+
+        /// <summary>
+        /// Exec Method
+        /// </summary>
+        /// <remarks>
+        /// Run a string containing Python code.
+        /// It's a subset of Python exec function.
+        /// </remarks>
+        public static void Exec(string code, IntPtr? globals = null, IntPtr? locals = null)
+        {
+            PyObject result = RunString(code, globals, locals, RunFlagType.File);
+            if (result.obj != Runtime.PyNone)
+            {
+                throw new PythonException();
+            }
+            result.Dispose();
+        }
+
+
+        /// <summary>
+        /// RunString Method. Function has been deprecated and will be removed.
+        /// Use Exec/Eval/RunSimpleString instead.
+        /// </summary>
+        [Obsolete("RunString is deprecated and will be removed. Use Exec/Eval/RunSimpleString instead.")]
+        public static PyObject RunString(string code, IntPtr? globals = null, IntPtr? locals = null)
+        {
+            return RunString(code, globals, locals, RunFlagType.File);
+        }
+
+        /// <summary>
+        /// Internal RunString Method.
         /// </summary>
-        ///
         /// <remarks>
         /// Run a string containing Python code. Returns the result of
         /// executing the code string as a PyObject instance, or null if
         /// an exception was raised.
         /// </remarks>
-        public static PyObject RunString(string code)
+        internal static PyObject RunString(string code, IntPtr? globals, IntPtr? locals, RunFlagType flag)
         {
-            IntPtr globals = Runtime.PyEval_GetGlobals();
-            IntPtr locals = Runtime.PyDict_New();
-
-            IntPtr builtins = Runtime.PyEval_GetBuiltins();
-            Runtime.PyDict_SetItemString(locals, "__builtins__", builtins);
-
-            IntPtr flag = (IntPtr)257; /* Py_file_input */
-            IntPtr result = Runtime.PyRun_String(code, flag, globals, locals);
-            Runtime.XDecref(locals);
-            if (result == IntPtr.Zero)
+            var borrowedGlobals = true;
+            if (globals == null)
             {
-                return null;
+                globals = Runtime.PyEval_GetGlobals();
+                if (globals == IntPtr.Zero)
+                {
+                    globals = Runtime.PyDict_New();
+                    Runtime.PyDict_SetItemString(
+                        globals.Value, "__builtins__",
+                        Runtime.PyEval_GetBuiltins()
+                    );
+                    borrowedGlobals = false;
+                }
             }
-            return new PyObject(result);
-        }
 
-        public static PyObject RunString(string code, IntPtr globals, IntPtr locals)
-        {
-            IntPtr flag = (IntPtr)257; /* Py_file_input */
-            IntPtr result = Runtime.PyRun_String(code, flag, globals, locals);
-            if (result == IntPtr.Zero)
+            var borrowedLocals = true;
+            if (locals == null)
             {
-                return null;
+                locals = Runtime.PyDict_New();
+                borrowedLocals = false;
+            }
+
+            try
+            {
+                IntPtr result = Runtime.PyRun_String(
+                    code, (IntPtr)flag, globals.Value, locals.Value
+                );
+
+                Runtime.CheckExceptionOccurred();
+
+                return new PyObject(result);
+            }
+            finally
+            {
+                if (!borrowedLocals)
+                {
+                    Runtime.XDecref(locals.Value);
+                }
+                if (!borrowedGlobals)
+                {
+                    Runtime.XDecref(globals.Value);
+                }
             }
-            return new PyObject(result);
         }
     }
 
+    public enum RunFlagType
+    {
+        Single = 256,
+        File = 257, /* Py_file_input */
+        Eval = 258
+    }
+
     public static class Py
     {
         public static GILState GIL()
         {
             if (!PythonEngine.IsInitialized)
+            {
                 PythonEngine.Initialize();
+            }
 
             return new GILState();
         }
@@ -479,19 +567,29 @@ namespace Python.Runtime
         public static KeywordArguments kw(params object[] kv)
         {
             var dict = new KeywordArguments();
-            if (kv.Length%2 != 0)
+            if (kv.Length % 2 != 0)
+            {
                 throw new ArgumentException("Must have an equal number of keys and values");
-            for (int i = 0; i < kv.Length; i += 2)
+            }
+            for (var i = 0; i < kv.Length; i += 2)
             {
                 IntPtr value;
                 if (kv[i + 1] is PyObject)
+                {
                     value = ((PyObject)kv[i + 1]).Handle;
+                }
                 else
+                {
                     value = Converter.ToPython(kv[i + 1], kv[i + 1]?.GetType());
+                }
                 if (Runtime.PyDict_SetItemString(dict.Handle, (string)kv[i], value) != 0)
+                {
                     throw new ArgumentException(string.Format("Cannot add key '{0}' to dictionary.", (string)kv[i]));
+                }
                 if (!(kv[i + 1] is PyObject))
+                {
                     Runtime.XDecref(value);
+                }
             }
             return dict;
         }
@@ -500,5 +598,39 @@ namespace Python.Runtime
         {
             return PythonEngine.ImportModule(name);
         }
+
+        public static void SetArgv()
+        {
+            IEnumerable<string> args;
+            try
+            {
+                args = Environment.GetCommandLineArgs();
+            }
+            catch (NotSupportedException)
+            {
+                args = Enumerable.Empty<string>();
+            }
+
+            SetArgv(
+                new[] { "" }.Concat(
+                    Environment.GetCommandLineArgs().Skip(1)
+                )
+            );
+        }
+
+        public static void SetArgv(params string[] argv)
+        {
+            SetArgv(argv as IEnumerable<string>);
+        }
+
+        public static void SetArgv(IEnumerable<string> argv)
+        {
+            using (GIL())
+            {
+                string[] arr = argv.ToArray();
+                Runtime.PySys_SetArgvEx(arr.Length, arr, 0);
+                Runtime.CheckExceptionOccurred();
+            }
+        }
     }
 }
