@@ -1,13 +1,11 @@
 using System;
-using System.Collections;
 using System.Reflection;
 
 namespace Python.Runtime
 {
-    //========================================================================
-    // Implements a Python type that provides access to CLR object methods.
-    //========================================================================
-
+    /// <summary>
+    /// Implements a Python type that provides access to CLR object methods.
+    /// </summary>
     internal class TypeMethod : MethodObject
     {
         public TypeMethod(Type type, string name, MethodInfo[] info) :
@@ -22,21 +20,20 @@ namespace Python.Runtime
 
         public override IntPtr Invoke(IntPtr ob, IntPtr args, IntPtr kw)
         {
-            MethodInfo mi = this.info[0];
-            Object[] arglist = new Object[3];
+            MethodInfo mi = info[0];
+            var arglist = new object[3];
             arglist[0] = ob;
             arglist[1] = args;
             arglist[2] = kw;
 
             try
             {
-                Object inst = null;
+                object inst = null;
                 if (ob != IntPtr.Zero)
                 {
                     inst = GetManagedObject(ob);
                 }
-                return (IntPtr)mi.Invoke(inst, BindingFlags.Default, null, arglist,
-                    null);
+                return (IntPtr)mi.Invoke(inst, BindingFlags.Default, null, arglist, null);
             }
             catch (Exception e)
             {
@@ -45,4 +42,4 @@ namespace Python.Runtime
             }
         }
     }
-}
\ No newline at end of file
+}
